Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1677)

Unified Diff: third_party/WebKit/Source/platform/web_process_memory_dump_impl.h

Issue 1738843002: Refactoring: Unify WebMemoryAllocatorDump and WebMemoryAllocatorDumpImpl Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: (rebasing) Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/web_process_memory_dump_impl.h
diff --git a/third_party/WebKit/Source/platform/web_process_memory_dump_impl.h b/third_party/WebKit/Source/platform/web_process_memory_dump_impl.h
index 2c5db22436002057f1408542bedd3703b7438b6f..2d62769a99a7fe4b9876dd24586ee0d6b83d1696 100644
--- a/third_party/WebKit/Source/platform/web_process_memory_dump_impl.h
+++ b/third_party/WebKit/Source/platform/web_process_memory_dump_impl.h
@@ -29,8 +29,6 @@ class SkiaTraceMemoryDumpImpl;
namespace blink {
-class WebMemoryAllocatorDumpImpl;
-
// Implements the blink::WebProcessMemoryDump interface by means of proxying the
// calls to createMemoryAllocatorDump() to the underlying
// base::trace_event::ProcessMemoryDump instance.
@@ -98,13 +96,13 @@ class PLATFORM_EXPORT WebProcessMemoryDumpImpl final
// TODO(ssid): Remove it once this information is added to ProcessMemoryDump.
base::trace_event::MemoryDumpLevelOfDetail level_of_detail_;
// Reverse index of MemoryAllocatorDump -> WebMemoryAllocatorDumpImpl wrapper.
// By design WebMemoryDumpProvider(s) are not supposed to hold the pointer
// to the WebProcessMemoryDump passed as argument of the onMemoryDump() call.
// Those pointers are valid only within the scope of the call and can be
// safely torn down once the WebProcessMemoryDumpImpl itself is destroyed.
HashMap<base::trace_event::MemoryAllocatorDump*,
- OwnPtr<WebMemoryAllocatorDumpImpl>> memory_allocator_dumps_;
+ OwnPtr<WebMemoryAllocatorDump>> memory_allocator_dumps_;
// Stores SkTraceMemoryDump for the current ProcessMemoryDump.
std::vector<scoped_ptr<skia::SkiaTraceMemoryDumpImpl>> sk_trace_dump_list_;
@@ -98,13 +96,13 @@ class PLATFORM_EXPORT WebProcessMemoryDumpImpl final
// TODO(ssid): Remove it once this information is added to ProcessMemoryDump.
base::trace_event::MemoryDumpLevelOfDetail level_of_detail_;
- // Reverse index of MemoryAllocatorDump -> WebMemoryAllocatorDumpImpl wrapper.
+ // Reverse index of MemoryAllocatorDump -> WebMemoryAllocatorDump wrapper.
// By design WebMemoryDumpProvider(s) are not supposed to hold the pointer
// to the WebProcessMemoryDump passed as argument of the onMemoryDump() call.

Powered by Google App Engine
This is Rietveld 408576698